@@ -5,7 +5,7 @@
 
     Test various Sphinx-specific markup extensions.
 
-    :copyright: Copyright 2007-2015 by the Sphinx team, see AUTHORS.
+    :copyright: Copyright 2007-2016 by the Sphinx team, see AUTHORS.
     :license: BSD, see LICENSE for details.
 """
 
@@ -103,13 +103,13 @@ def test_inline():
     # interpolation of arrows in menuselection
     yield (verify, ':menuselection:`a --> b`',
            u'<p><span class="menuselection">a \N{TRIANGULAR BULLET} b</span></p>',
-           '\\emph{a \\(\\rightarrow\\) b}')
+           '\\menuselection{a \\(\\rightarrow\\) b}')
 
     # interpolation of ampersands in guilabel/menuselection
     yield (verify, ':guilabel:`&Foo -&&- &Bar`',
            u'<p><span class="guilabel"><span class="accelerator">F</span>oo '
            '-&amp;- <span class="accelerator">B</span>ar</span></p>',
-           r'\emph{\DUspan{accelerator}{F}oo -\&- \DUspan{accelerator}{B}ar}')
+           r'\menuselection{\accelerator{F}oo -\&- \accelerator{B}ar}')
 
     # non-interpolation of dashes in option role
     yield (verify_re, ':option:`--with-option`',
